@@ -18,10 +18,7 @@ weights_control <- function(weights,start,hf_length,hf_freq) {
 }
 
 bflSmooth_matrices_impl <- function(lf_length,ratio,weights,lfserie.is.rate) {
-  if (is.null(weights)) {
-    aggregated_weights <- rep(1,lf_length)
-    weights <- 1
-  }
+  if (is.null(weights)) weights <- 1
   else {
     aggregated_weights <- aggregate.ts(weights,frequency(weights)/ratio)
     weights <- weights/ts_expand(aggregated_weights,
@@ -38,7 +35,7 @@ bflSmooth_matrices_impl <- function(lf_length,ratio,weights,lfserie.is.rate) {
   # A * as.numeric(x) stands for diag(x) %*% A
   # t(t(A) * as.numeric(x)) stands for A %*% diag(x)
   
-  if (lfserie.is.rate||is.null(weights)) {
+  if (lfserie.is.rate||identical(weights,1)) {
     list(m1=m1,
          cprod1=cprod1,
          cprod2=cprod2)
@@ -49,9 +46,16 @@ bflSmooth_matrices_impl <- function(lf_length,ratio,weights,lfserie.is.rate) {
   }
 }
 
-# This function generates a wrapper of bflSmooth_matrices_impl that gives the
-# same results but uses cache, which is useful considering a lot of similar
-bflSmooth_matrices_generator <- function(cache_size=100L) {
+#' Generating a clone for bflSmooth_matrices_impl
+#' 
+#' This *function factory* returns a clone of bflSmooth_matrices_impl that gives
+#' the same results than the original function but uses cache, which is useful
+#' considering people would often use a lot of similar calls.
+#' 
+#' bflSmooth_matrices_factory is only run at build time.
+#' 
+#' @keywords internal
+bflSmooth_matrices_factory <- function(cache_size=100L) {
   cache <- vector("list",cache_size)
   cache_next <- 1L
   function(lf_length,ratio,weights,lfserie.is.rate) {
@@ -68,27 +72,29 @@ bflSmooth_matrices_generator <- function(cache_size=100L) {
   }
 }
 
-bflSmooth_matrices <- bflSmooth_matrices_generator()
+bflSmooth_matrices <- bflSmooth_matrices_factory()
 
 #' Smooth a time serie
 #' 
-#' bflSmooth smoothes a time-serie into a time serie of a higher frequency that exactly
-#' aggregate into the higher one. The process followed is Boot, Feibes and Lisman, which
-#' minimizes the squares of the variations.
+#' bflSmooth smoothes a time-serie into a time serie of a higher frequency that
+#' exactly aggregates into the higher one. The process followed is Boot, Feibes
+#' and Lisman, which minimizes the squares of the variations.
 #' 
 #' If `weights` isn't `NULL` the results depends of `lfserie.is.rate` :
 #' 
-#' * if `FALSE` the rate output/weights is smoothed with the constraint that the aggregated output
-#' is equal to lfserie.
-#' * if `TRUE` the output is the rate to be smoothed, and the output is the aggregated rate.
-#' 
-#' @author
-#' Arnaud Feldmann
+#' * if `FALSE` the rate output/weights is smoothed with the constraint that the
+#' aggregated output is equal to the input lfserie.
+#' * if `TRUE` the input lfserie is the rate to be smoothed, with the constraint
+#' that the low-frequency weighted means of the output are equal to
+#' lfserie.
 #' 
 #' @param lfserie a time-serie to be smoothed
-#' @param nfrequency the new high frequency. It must be a multiple of the low frequency.
-#' @param weights NULL or a time-serie of the same size than the expected high-frequency serie.
-#' @param lfserie.is.rate TRUE or FALSE. only means a thing if weights isn't NULL.
+#' @param nfrequency the new high frequency. It must be a multiple of the low
+#' frequency.
+#' @param weights NULL or a time-serie of the same size than the expected
+#' high-frequency serie.
+#' @param lfserie.is.rate TRUE or FALSE. only means a thing if weights isn't
+#' NULL.
 #' 
 #' @return A time serie of frequency nfrequency
 #' 
@@ -101,7 +107,8 @@ bflSmooth <- function(lfserie,nfrequency,weights=NULL,lfserie.is.rate=FALSE) {
   if (nfrequency %% tsplf[3L] != 0L) stop("The new frequency must be a multiple of the lower one", call. = FALSE)
   if (!is.null(dim(lfserie)) && dim(lfserie)[2L] != 1) stop("The low frequency serie must be one-dimensional", call. = FALSE)
   if (is.null(weights) && lfserie.is.rate) {
-    warning("weights is NULL. Ignoring lfserie.is.rate")
+    warning("weights is NULL. Ignoring lfserie.is.rate",call. = FALSE)
+    lfserie.is.rate <- FALSE
   }
   
   ratio <- nfrequency/tsplf[3L]
@@ -119,4 +126,4 @@ bflSmooth <- function(lfserie,nfrequency,weights=NULL,lfserie.is.rate=FALSE) {
   res <- cumsum(c(x11,matrices$cprod2 %*% (as.numeric(lfserie)-matrices$m1*x11)))
   if (!lfserie.is.rate && !is.null(weights)) res <- res * as.numeric(weights)
   ts(res,start=tsplf[1L],frequency = nfrequency)
-}
\ No newline at end of file
+}
